@@ -174,7 +174,7 @@ def histogram(stream, minimum=None, maximum=None, buckets=None, custbuckets=None
     print "# NumSamples = %d; Min = %0.2f; Max = %0.2f" % (samples, min_v, max_v)
     if skipped:
         print "# %d value%s outside of min/max" % (skipped, skipped > 1 and 's' or '')
-    if calc_mvsd:
+    if calc_msvd:
         print "# Mean = %f; Variance = %f; SD = %f; Median %f" % (mvsd.mean(), mvsd.var(), mvsd.sd(), median(accepted_data))
     print "# each ∎ represents a count of %d" % bucket_scale
     bucket_min = min_v
